==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/RenderRequestedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { RenderRequestedEventArgsDescription } from "./RenderRequestedEventArgsDescription";
/**
 * @hidden
 */
export let RenderRequestedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class RenderRequestedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (RenderRequestedEventArgsDescriptionMetadata.a == null) {
                RenderRequestedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                RenderRequestedEventArgsDescriptionMetadata.c(RenderRequestedEventArgsDescriptionMetadata.a);
            }
            if (a.k(RenderRequestedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(RenderRequestedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("Animate", "Boolean");
        }
        static d(a) {
            RenderRequestedEventArgsDescriptionMetadata.b(a);
            a.ad("RenderRequestedEventArgs", () => new RenderRequestedEventArgsDescription());
            a.ac("RenderRequestedEventArgs", RenderRequestedEventArgsDescriptionMetadata.a);
        }
    }
    RenderRequestedEventArgsDescriptionMetadata.$t = markType(RenderRequestedEventArgsDescriptionMetadata, 'RenderRequestedEventArgsDescriptionMetadata');
    RenderRequestedEventArgsDescriptionMetadata.a = null;
    return RenderRequestedEventArgsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/RenderRequestedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { RenderRequestedEventArgsDescription } from "./RenderRequestedEventArgsDescription";
/**
 * @hidden
 */
export let RenderRequestedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class RenderRequestedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (RenderRequestedEventArgsDescriptionMetadata.a == null) {
                RenderRequestedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                RenderRequestedEventArgsDescriptionMetadata.c(RenderRequestedEventArgsDescriptionMetadata.a);
            }
            if (a.k(RenderRequestedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(RenderRequestedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("Animate", "Boolean");
        }
        static d(a) {
            RenderRequestedEventArgsDescriptionMetadata.b(a);
            a.ae("RenderRequestedEventArgs", () => new RenderRequestedEventArgsDescription());
            a.ad("RenderRequestedEventArgs", RenderRequestedEventArgsDescriptionMetadata.a);
        }
    }
    RenderRequestedEventArgsDescriptionMetadata.$t = markType(RenderRequestedEventArgsDescriptionMetadata, 'RenderRequestedEventArgsDescriptionMetadata');
    RenderRequestedEventArgsDescriptionMetadata.a = null;
    return RenderRequestedEventArgsDescriptionMetadata;
})();
